@@ -6,6 +6,7 @@ function bluer_ugv_swallow_dataset_combine() {
     local do_upload=$(bluer_ai_option_int "$options" upload 0)
     local count=$(bluer_ai_option "$options" count -1)
     local recent=$(bluer_ai_option_int "$options" recent 1)
+    local sequence=$(bluer_ai_option "$options" sequence -1)
     local split=$(bluer_ai_option_int "$options" split 1)
 
     local object_name=$(bluer_ai_clarify_object $2 swallow-dataset-$(bluer_ai_string_timestamp_short))
@@ -17,6 +18,7 @@ function bluer_ugv_swallow_dataset_combine() {
         --download $do_download \
         --object_name $object_name \
         --recent $recent \
+        --sequence $sequence \
         --split $split \
         "${@:3}"
     [[ $? -ne 0 ]] && return 1
