@@ -12,10 +12,21 @@ assets2_bluer_robin = f"{assets2}/bluer-robin"
 assets2_bluer_swallow = f"{assets2}/bluer-swallow"
 assets2_bluer_sparrow = f"{assets2}/bluer-sparrow"
 
+# design
 bluer_ugv_mechanical_design = f"{github_kamangir}/bluer-ugv-mechanical-design/"
+
+bluer_robin_design = f"{bluer_ugv_mechanical_design}/blob/main/bluer_robin"
+
+bluer_swallow_electrical_design = (
+    f"{bluer_ugv_mechanical_design}/blob/main/bluer_swallow/electrical"
+)
+bluer_swallow_mechanical_design = (
+    f"{bluer_ugv_mechanical_design}/blob/main/bluer_swallow/mechanical"
+)
+bluer_swallow_ultrasonic_sensor_design = (
+    f"{bluer_ugv_mechanical_design}/blob/main/bluer_swallow/ultrasonic-sensors"
+)
+
 bluer_sparrow_mechanical_design = (
     f"{bluer_ugv_mechanical_design}/blob/main/bluer_sparrow"
 )
-bluer_swallow_mechanical_design = (
-    f"{bluer_ugv_mechanical_design}/blob/main/bluer_swallow"
-)
