@@ -23,3 +23,7 @@ BLUER_UGV_SWALLOW_NAVIGATION_MODEL = get_env("BLUER_UGV_SWALLOW_NAVIGATION_MODEL
 BLUER_UGV_SWALLOW_YOLO_MODEL = get_env("BLUER_UGV_SWALLOW_YOLO_MODEL")
 
 BLUER_UGV_SWALLOW_YOLO_DATASET_LIST = get_env("BLUER_UGV_SWALLOW_YOLO_DATASET_LIST")
+
+BLUER_UGV_ULTRASONIC_SENSOR_TEST_OBJECT = get_env(
+    "BLUER_UGV_ULTRASONIC_SENSOR_TEST_OBJECT"
+)
